@@ -1,5 +1,5 @@
 from dataclasses import dataclass, field
-from typing import List
+from typing import List, Optional
 
 
 @dataclass
@@ -9,6 +9,20 @@ class NodeVersion:
     deprecated: bool
     id: str
     version: str
+    download_url: str
+
+
+@dataclass
+class Node:
+    id: str
+    name: str
+    description: str
+    author: Optional[str] = None
+    license: Optional[str] = None
+    icon: Optional[str] = None
+    repository: Optional[str] = None
+    tags: List[str] = field(default_factory=list)
+    latest_version: Optional[NodeVersion] = None
 
 
 @dataclass
@@ -39,6 +53,12 @@ class ComfyConfig:
     models: List[Model] = field(default_factory=list)
 
 
+@dataclass
+class License:
+    file: str = ""
+    text: str = ""
+
+
 @dataclass
 class ProjectConfig:
     name: str = ""
@@ -46,7 +66,7 @@ class ProjectConfig:
     version: str = "1.0.0"
     requires_python: str = ">= 3.9"
     dependencies: List[str] = field(default_factory=list)
-    license: str = ""
+    license: License = field(default_factory=License)
     urls: URLs = field(default_factory=URLs)
 
 
